import pandas as pd
import numpy as np
from datetime import datetime, timedelta

# Parameters for data generation
num_customers = 1000
start_date = datetime(2024, 10, 19)
end_date = datetime(2024, 10, 20)
categories = ["electronics", "books", "clothing", "groceries", "toys"]

# Generate customer IDs and random timestamps
customer_ids = np.random.randint(1, 11, size=num_customers)  # IDs range from 1 to 10

timestamps = [
    start_date + timedelta(minutes=np.random.randint(0, 24 * 60))
    for _ in range(num_customers)
]

# Generate random purchase amounts and categories
purchase_amounts = np.round(np.random.uniform(5.0, 500.0, size=num_customers), 2)
purchase_categories = np.random.choice(categories, size=num_customers)

# Create the DataFrame
data = {
    "customer_id": customer_ids,
    "event_timestamp": pd.to_datetime(timestamps).tz_localize("UTC"),
    "purchase_amount": purchase_amounts,
    "purchase_category": purchase_categories,
}
df = pd.DataFrame(data)

# Save to Parquet file
output_path = "feature_repo/data/customer_purchases_29102024.parquet"
df.to_parquet(output_path, index=False)

print(f"Generated data saved to {output_path}")
print(df)
